//
//  ZXLHeaderCell.m
//  TOPULL
//
//  Created by zxl on 2017/12/22.
//  Copyright © 2017年 EM. All rights reserved.
//

#import "ZXLHeaderCell.h"
#import "Masonry.h"
#import "COMMON.h"

@interface ZXLHeaderCell()

@property (nonatomic, strong)UIView *gradientBgView;
@property (nonatomic, strong) CAShapeLayer *sLayer;
@property (nonatomic, strong) CAGradientLayer *gLayer;

@end

@implementation ZXLHeaderCell

- (instancetype)initWithStyle:(UITableViewCellStyle)style reuseIdentifier:(NSString *)reuseIdentifier
{
    self = [super initWithStyle:style reuseIdentifier:reuseIdentifier];
    if (self) {
        self.backgroundColor = [UIColor whiteColor];
        [self addSubview:self.gradientBgView];
        [self.gradientBgView mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.top.right.bottom.equalTo(self);
        }];
    }
    return self;
}


- (void)drawRect:(CGRect)rect
{
    [super drawRect:rect];
    CGFloat x1 = 0, y1 = self.gradientBgView.frame.size.height - 44, x2 = CGRectGetMidX(self.gradientBgView.frame), y2 = CGRectGetMaxY(self.gradientBgView.frame), x3 = rect.size.width, y3 = y1;
    CGPoint p0 = CGPointMake(x1, x1);
    CGPoint p1 = CGPointMake(x1, y1);
    CGPoint p3 = CGPointMake(x3, 0);
    //计算圆心，半径和弧度
    CGFloat a = 2*(x2-x1);
    CGFloat b = 2*(y2-y1);
    CGFloat c = x2*x2+y2*y2-x1*x1-y1*y1;
    CGFloat d = 2*(x3-x2);
    CGFloat e = 2*(y3-y2);
    CGFloat f = x3*x3+y3*y3-x2*x2-y2*y2;
    CGFloat x = (b*f-e*c)/(b*d-e*a);
    CGFloat y = (d*c-a*f)/(b*d-e*a);
    CGFloat r = sqrt((x-x1)*(x-x1)+(y-y1)*(y-y1));
    
    CGFloat endAngle = acos((x3-x)/r);
    CGFloat startAngle = M_PI-acos((x-x1)/r);
    
    UIBezierPath *path = [UIBezierPath bezierPath];
    [path moveToPoint:p0];
    [path addLineToPoint:p1];
    [path addArcWithCenter:CGPointMake(x, y) radius:r startAngle:startAngle endAngle:endAngle clockwise:NO];
    [path addLineToPoint:p3];
    
    [path closePath];
    
    self.gLayer.frame = self.gradientBgView.bounds;
    [self.gradientBgView.layer insertSublayer:self.gLayer atIndex:0];
    
    self.sLayer.path = path.CGPath;
    self.sLayer.position = CGPointZero;
    self.sLayer.frame = self.gradientBgView.bounds;
    self.gradientBgView.layer.mask = self.sLayer;
}

#pragma mark - lazy
- (UIView *)gradientBgView
{
    if (_gradientBgView) {
        return _gradientBgView;
    }
    _gradientBgView = [[UIView alloc]init];
    return _gradientBgView;
}
- (CAShapeLayer *)sLayer
{
    if (_sLayer) {
        return _sLayer;
    }
    _sLayer = [CAShapeLayer layer];
    return _sLayer;
}

- (CAGradientLayer *)gLayer
{
    if (_gLayer) {
        return _gLayer;
    }
    _gLayer = [CAGradientLayer layer];
    _gLayer.colors = @[(__bridge id)RGB(255, 59, 59).CGColor,(__bridge id)RGB(255, 59, 59).CGColor];
    
    return _gLayer;
}

@end
